pub struct ListTableMetadataFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListTableMetadata.
Lists the metadata for the tables in the specified data catalog database.
Implementations
Sourceimpl ListTableMetadataFluentBuilder
impl ListTableMetadataFluentBuilder
Sourcepub fn as_input(&self) -> &ListTableMetadataInputBuilder
pub fn as_input(&self) -> &ListTableMetadataInputBuilder
Access the ListTableMetadata as a reference.
Sourcepub async fn send(
self,
) -> Result<ListTableMetadataOutput, SdkError<ListTableMetadataError, HttpResponse>>
pub async fn send( self, ) -> Result<ListTableMetadataOutput, SdkError<ListTableMetadataError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListTableMetadataOutput, ListTableMetadataError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListTableMetadataOutput, ListTableMetadataError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListTableMetadataPaginator
pub fn into_paginator(self) -> ListTableMetadataPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn catalog_name(self, input: impl Into<String>) -> Self
pub fn catalog_name(self, input: impl Into<String>) -> Self
The name of the data catalog for which table metadata should be returned.
Sourcepub fn set_catalog_name(self, input: Option<String>) -> Self
pub fn set_catalog_name(self, input: Option<String>) -> Self
The name of the data catalog for which table metadata should be returned.
Sourcepub fn get_catalog_name(&self) -> &Option<String>
pub fn get_catalog_name(&self) -> &Option<String>
The name of the data catalog for which table metadata should be returned.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database for which table metadata should be returned.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database for which table metadata should be returned.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database for which table metadata should be returned.
Sourcepub fn expression(self, input: impl Into<String>) -> Self
pub fn expression(self, input: impl Into<String>) -> Self
A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.
Sourcepub fn set_expression(self, input: Option<String>) -> Self
pub fn set_expression(self, input: Option<String>) -> Self
A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.
Sourcepub fn get_expression(&self) -> &Option<String>
pub fn get_expression(&self) -> &Option<String>
A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Specifies the maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Specifies the maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Specifies the maximum number of results to return.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.