#[non_exhaustive]pub struct ListTableMetadataInputBuilder { /* private fields */ }Expand description
A builder for ListTableMetadataInput.
Implementations
Sourceimpl ListTableMetadataInputBuilder
impl ListTableMetadataInputBuilder
Sourcepub fn catalog_name(self, input: impl Into<String>) -> Self
pub fn catalog_name(self, input: impl Into<String>) -> Self
The name of the data catalog for which table metadata should be returned.
This field is required.Sourcepub fn set_catalog_name(self, input: Option<String>) -> Self
pub fn set_catalog_name(self, input: Option<String>) -> Self
The name of the data catalog for which table metadata should be returned.
Sourcepub fn get_catalog_name(&self) -> &Option<String>
pub fn get_catalog_name(&self) -> &Option<String>
The name of the data catalog for which table metadata should be returned.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database for which table metadata should be returned.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database for which table metadata should be returned.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database for which table metadata should be returned.
Sourcepub fn expression(self, input: impl Into<String>) -> Self
pub fn expression(self, input: impl Into<String>) -> Self
A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.
Sourcepub fn set_expression(self, input: Option<String>) -> Self
pub fn set_expression(self, input: Option<String>) -> Self
A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.
Sourcepub fn get_expression(&self) -> &Option<String>
pub fn get_expression(&self) -> &Option<String>
A regex filter that pattern-matches table names. If no expression is supplied, metadata for all tables are listed.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
Specifies the maximum number of results to return.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
Specifies the maximum number of results to return.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
Specifies the maximum number of results to return.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn build(self) -> Result<ListTableMetadataInput, BuildError>
pub fn build(self) -> Result<ListTableMetadataInput, BuildError>
Consumes the builder and constructs a ListTableMetadataInput.
Sourceimpl ListTableMetadataInputBuilder
impl ListTableMetadataInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListTableMetadataOutput, SdkError<ListTableMetadataError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListTableMetadataOutput, SdkError<ListTableMetadataError, HttpResponse>>
Sends a request with this input using the given client.