#[non_exhaustive]pub struct ListTableMetadataOutputBuilder { /* private fields */ }Expand description
A builder for ListTableMetadataOutput.
Implementations
Sourceimpl ListTableMetadataOutputBuilder
impl ListTableMetadataOutputBuilder
Sourcepub fn table_metadata_list(self, input: TableMetadata) -> Self
pub fn table_metadata_list(self, input: TableMetadata) -> Self
Appends an item to table_metadata_list.
To override the contents of this collection use set_table_metadata_list.
A list of table metadata.
Sourcepub fn set_table_metadata_list(self, input: Option<Vec<TableMetadata>>) -> Self
pub fn set_table_metadata_list(self, input: Option<Vec<TableMetadata>>) -> Self
A list of table metadata.
Sourcepub fn get_table_metadata_list(&self) -> &Option<Vec<TableMetadata>>
pub fn get_table_metadata_list(&self) -> &Option<Vec<TableMetadata>>
A list of table metadata.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> ListTableMetadataOutput
pub fn build(self) -> ListTableMetadataOutput
Consumes the builder and constructs a ListTableMetadataOutput.